@@ -1,6 +1,7 @@
 package Reddit::Client;
 
-our $VERSION = '1.242';
+our $VERSION = '1.243';
+# 1.243 rolled back change making request_errors default
 # 1.242 request_errors (print the content of errors) is now true by default.
 # 1.24 ban function
 # 1.241 fix newline in request->send
@@ -205,7 +206,7 @@ sub new {
 		 croak "param 'user_agent' is required.";
 	}
 	$self->{user_agent} 	= $param{user_agent};
-	$self->{request_errors} = $param{request_errors} || 1;
+	$self->{request_errors} = $param{print_request_errors} || $param{request_errors} || 0;
 	$self->{print_response} = $param{print_response} || 0;
 	$self->{print_request}  = $param{print_request} || 0;
 
